@@ -29,6 +29,7 @@ __all__ = [
     "write",
     "version_info",
     "__version__",
+    "Sentinel",
 ]
 
 versions = {
@@ -146,7 +147,7 @@ def read(fp, as_version, capture_validation_error=None, **kwargs):
     fp : file or str
         A file-like object with a read method that returns unicode (use
         ``io.open()`` in Python 2), or a path to a file.
-    as_version: int
+    as_version : int
         The version of the notebook format to return.
         The notebook will be converted, if necessary.
         Pass nbformat.NO_CONVERT to prevent conversion.
