@@ -11,12 +11,13 @@
 import re
 import warnings
 
-warnings.warning(
-    """nbformat.current is deprecated.
+warnings.warn(
+    """nbformat.current is deprecated since before nbformat 3.0
 
 - use nbformat for read/write/validate public API
 - use nbformat.vX directly to composing notebooks of a particular version
-"""
+""",
+    DeprecationWarning,
 )
 
 from traitlets.log import get_logger
@@ -79,12 +80,14 @@ current_nbformat_module = _v_latest.__name__
 
 
 class NBFormatError(ValueError):
+    """An error raised for an nbformat error."""
+
     pass
 
 
 def _warn_format():
-    warnings.warning(
-        """Non-JSON file support in nbformat is deprecated.
+    warnings.warn(
+        """Non-JSON file support in nbformat is deprecated since nbformat 1.0.
     Use nbconvert to create files of other formats."""
     )
 
@@ -107,13 +110,21 @@ def parse_py(s, **kwargs):
 
 def reads_json(nbjson, **kwargs):
     """DEPRECATED, use reads"""
-    warnings.warning("reads_json is deprecated, use reads")
+    warnings.warn(
+        "reads_json is deprecated since nbformat 3.0, use reads",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     return reads(nbjson)
 
 
 def writes_json(nb, **kwargs):
     """DEPRECATED, use writes"""
-    warnings.warning("writes_json is deprecated, use writes")
+    warnings.warn(
+        "writes_json is deprecated since nbformat 3.0, use writes",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     return writes(nb, **kwargs)
 
 
@@ -158,7 +169,9 @@ def reads(s, format="DEPRECATED", version=current_nbformat, **kwargs):
     nb = reader_reads(s, **kwargs)
     nb = convert(nb, version)
     try:
-        validate(nb)
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", category=DeprecationWarning)
+            validate(nb, repair_duplicate_cell_ids=False)
     except ValidationError as e:
         get_logger().error("Notebook JSON is invalid: %s", e)
     return nb
@@ -186,7 +199,9 @@ def writes(nb, format="DEPRECATED", version=current_nbformat, **kwargs):
         _warn_format()
     nb = convert(nb, version)
     try:
-        validate(nb)
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", category=DeprecationWarning)
+            validate(nb, repair_duplicate_cell_ids=False)
     except ValidationError as e:
         get_logger().error("Notebook JSON is invalid: %s", e)
     return versions[version].writes_json(nb, **kwargs)
